@@ -2,9 +2,9 @@
  * 
  * hmm_bc.c
  * 
- * copyright (c) 2001-3, Karl W Broman, Johns Hopkins University
+ * copyright (c) 2001-4, Karl W Broman, Johns Hopkins University
  *
- * last modified Oct, 2003
+ * last modified Nov, 2004
  * first written Feb, 2001
  *
  * Licensed under the GNU General Public License version 2 (June, 1991)
@@ -78,11 +78,11 @@ void sim_geno_bc(int *n_ind, int *n_pos, int *n_draws, int *geno,
 
 void est_map_bc(int *n_ind, int *n_mar, int *geno, double *rf, 
 		double *error_prob, double *loglik, int *maxit, 
-		double *tol, int *trace)
+		double *tol, int *verbose)
 {
   est_map(*n_ind, *n_mar, 2, geno, rf, rf, *error_prob, 
 	  init_bc, emit_bc, step_bc, nrec_bc, nrec_bc,
-	  loglik, *maxit, *tol, 0, *trace);
+	  loglik, *maxit, *tol, 0, *verbose);
 }
 
 void argmax_geno_bc(int *n_ind, int *n_pos, int *geno, 
